The cell_fill() helper function is to be used with the tab_style()
function, which itself allows for the setting of custom styles to one or more
cells. Specifically, the call to cell_fill() should be bound to the
styles argument of tab_style().
cell_fill(color = "#D3D3D3", alpha = NULL)A list object of class cell_styles.
Cell fill color
scalar<character> // default: "#D3D3D3"
If nothing is provided for color then "#D3D3D3" (light gray) will be
used as a default.
Transparency value
scalar<numeric|integer>(0>=val>=1) // default: NULL (optional)
An optional alpha transparency value for the color as single value in the
range of 0 (fully transparent) to 1 (fully opaque). If not provided the
fill color will either be fully opaque or use alpha information from the
color value if it is supplied in the #RRGGBBAA format.
Let's use the exibble dataset to create a simple, two-column gt table
(keeping only the num and currency columns). Styles are added with
tab_style() in two separate calls (targeting different body cells with the
cells_body() helper function). With the cell_fill() helper funciton we
define cells with a "lightblue" background in one instance, and "gray85"
in the other.
exibble |>
dplyr::select(num, currency) |>
gt() |>
fmt_number(decimals = 1) |>
tab_style(
style = cell_fill(color = "lightblue"),
locations = cells_body(
columns = num,
rows = num >= 5000
)
) |>
tab_style(
style = cell_fill(color = "gray85"),
locations = cells_body(
columns = currency,
rows = currency < 100
)
)

8-25
v0.2.0.5 (March 31, 2020)
Other helper functions:
adjust_luminance(),
cell_borders(),
cell_text(),
cells_body(),
cells_column_labels(),
cells_column_spanners(),
cells_footnotes(),
cells_grand_summary(),
cells_row_groups(),
cells_source_notes(),
cells_stub_grand_summary(),
cells_stub_summary(),
cells_stubhead(),
cells_stub(),
cells_summary(),
cells_title(),
currency(),
default_fonts(),
define_units(),
escape_latex(),
from_column(),
google_font(),
gt_latex_dependencies(),
html(),
md(),
nanoplot_options(),
pct(),
px(),
random_id(),
stub(),
system_fonts()