Get the Open Office XML table tag content from a gt_tbl object as as a
single-element character vector.
as_word(
data,
align = "center",
caption_location = c("top", "bottom", "embed"),
caption_align = "left",
split = FALSE,
keep_with_next = TRUE
)A table object that is created using the gt() function.
An option for table alignment. Can either be "center" (the
default), "left", or "right".
Determines where the caption should be positioned.
This can either be "top" (the default), "bottom", or "embed".
Determines the alignment of the caption. This is
either "left" (the default), "center", or "right". This option is
only used when caption_location is not set as "embed".
A TRUE or FALSE (the default) value that indicates whether
to activate the Word option Allow row to break across pages.
A TRUE (the default) or FALSE value that indicates
whether a table should use Word option keep rows together.
Use gtcars to create a gt table. Add a header and then export as
OOXML code for Word.
tab_rtf <-
gtcars |>
dplyr::select(mfr, model) |>
dplyr::slice(1:2) |>
gt() |>
tab_header(
title = md("Data listing from **gtcars**"),
subtitle = md("`gtcars` is an R dataset")
) |>
as_word()
13-5
v0.7.0 (August 25, 2022)
Other table export functions:
as_latex(),
as_raw_html(),
as_rtf(),
extract_cells(),
extract_summary(),
gtsave()