A dataset that presents yearly, total populations of countries. Total
population is based on counts of all residents regardless of legal status or
citizenship. Country identifiers include the English-language country names,
and the 2- and 3-letter ISO 3166-1 country codes. Each row contains a
population value for a given year (from 1960 to 2021). Any NA values
for populations indicate the non-existence of the entity during that year.
countrypopsA tibble with 13,330 rows and 5 variables:
The name of the country.
The 2- and 3-letter ISO 3166-1 country codes.
The year for the population estimate.
The population estimate, midway through the year.
Here is a glimpse at the data available in countrypops.
dplyr::glimpse(countrypops)
#> Rows: 13,330
#> Columns: 5
#> $ country_name <chr> "Aruba", "Aruba", "Aruba", "Aruba", "Aruba", "Aruba", "~
#> $ country_code_2 <chr> "AW", "AW", "AW", "AW", "AW", "AW", "AW", "AW", "AW", "~
#> $ country_code_3 <chr> "ABW", "ABW", "ABW", "ABW", "ABW", "ABW", "ABW", "ABW",~
#> $ year <int> 1960, 1961, 1962, 1963, 1964, 1965, 1966, 1967, 1968, 1~
#> $ population <int> 54608, 55811, 56682, 57475, 58178, 58782, 59291, 59522,~
DATA-1

v0.2.0.5 (March 31, 2020)
Other datasets:
exibble,
gtcars,
metro,
pizzaplace,
rx_addv,
rx_adsl,
sp500,
sza,
towny