With numeric values in a gt table, we can perform currency-based
formatting. This function supports both automatic formatting with a
three-letter or numeric currency code. We can also specify a custom currency
that is formatted according to the output context with the currency()
helper function. Numeric formatting facilitated through the use of a locale
ID. We have fine control over the conversion from numeric values to currency
values, where we could take advantage of the following options:
the currency: providing a currency code or common currency name will
procure the correct currency symbol and number of currency subunits; we could
also use the currency() helper function to specify a custom currency
currency symbol placement: the currency symbol can be placed before or after the values
decimals/subunits: choice of the number of decimal places, and a choice of the decimal symbol, and an option on whether to include or exclude the currency subunits (decimal portion)
negative values: choice of a negative sign or parentheses for values less than zero
digit grouping separators: options to enable/disable digit separators and provide a choice of separator symbol
scaling: we can choose to scale targeted values by a multiplier value
large-number suffixing: larger figures (thousands, millions, etc.) can be autoscaled and decorated with the appropriate suffixes
pattern: option to use a text pattern for decoration of the formatted currency values
locale-based formatting: providing a locale ID will result in currency formatting specific to the chosen locale
We can use the info_currencies() function for a useful reference on all of
the possible inputs to the currency argument.
fmt_currency(
data,
columns = everything(),
rows = everything(),
currency = "USD",
use_subunits = TRUE,
decimals = NULL,
drop_trailing_dec_mark = TRUE,
use_seps = TRUE,
accounting = FALSE,
scale_by = 1,
suffixing = FALSE,
pattern = "{x}",
sep_mark = ",",
dec_mark = ".",
force_sign = FALSE,
placement = "left",
incl_space = FALSE,
system = c("intl", "ind"),
locale = NULL
)An object of class gt_tbl.
A table object that is created using the gt() function.
The columns to format. Can either be a series of column names
provided in c(), a vector of column indices, or a helper function
focused on selections. The select helper functions are: starts_with(),
ends_with(), contains(), matches(), one_of(), num_range(), and
everything().
Optional rows to format. Providing everything() (the
default) results in all rows in columns being formatted. Alternatively,
we can supply a vector of row captions within c(), a vector of row
indices, or a helper function focused on selections. The select helper
functions are: starts_with(), ends_with(), contains(), matches(),
one_of(), num_range(), and everything(). We can also use expressions
to filter down to the rows we need (e.g.,
[colname_1] > 100 & [colname_2] < 50).
The currency to use for the numeric value. This input can be
supplied as a 3-letter currency code (e.g., "USD" for U.S. Dollars,
"EUR" for the Euro currency). Use info_currencies() to get an
information table with all of the valid currency codes and examples of
each. Alternatively, we can provide a common currency name (e.g.,
"dollar", "pound", "yen", etc.) to simplify the process. Use
info_currencies() with the type == "symbol" option to view an
information table with all of the supported currency symbol names along
with examples.
We can also use the currency() helper function to specify a custom
currency, where the string could vary across output contexts. For example,
using currency(html = "ƒ", default = "f") would give us a suitable
glyph for the Dutch guilder in an HTML output table, and it would simply be
the letter "f" in all other output contexts). Please note that decimals
will default to 2 when using the currency() helper function.
If nothing is provided to currency then "USD" (U.S. dollars) will be
used.
An option for whether the subunits portion of a currency
value should be displayed. By default, this is TRUE.
An option to specify the exact number of decimal places to
use. The default number of decimal places is 2.
A logical value that determines whether decimal
marks should always appear even if there are no decimal digits to display
after formatting (e.g, 23 becomes 23.). The default for this is TRUE,
which means that trailing decimal marks are not shown.
An option to use digit group separators. The type of digit
group separator is set by sep_mark and overridden if a locale ID is
provided to locale. This setting is TRUE by default.
An option to use accounting style for values. With FALSE
(the default), negative values will be shown with a minus sign. Using
accounting = TRUE will put negative values in parentheses.
A value to scale the input. The default is 1.0. All numeric
values will be multiplied by this value first before undergoing formatting.
This value will be ignored if using any of the suffixing options (i.e.,
where suffixing is not set to FALSE).
An option to scale and apply suffixes to larger numbers
(e.g., 1924000 can be transformed to 1.92M). This option can accept a
logical value, where FALSE (the default) will not perform this
transformation and TRUE will apply thousands (K), millions (M),
billions (B), and trillions (T) suffixes after automatic value scaling.
We can also specify which symbols to use for each of the value ranges by
using a character vector of the preferred symbols to replace the defaults
(e.g., c("k", "Ml", "Bn", "Tr")).
Including NA values in the vector will ensure that the particular range
will either not be included in the transformation (e.g, c(NA, "M", "B", "T") won't modify numbers in the thousands range) or the range will
inherit a previous suffix (e.g., with c("K", "M", NA, "T"), all numbers
in the range of millions and billions will be in terms of millions).
Any use of suffixing (where it is not set expressly as FALSE) means
that any value provided to scale_by will be ignored.
If using system = "ind" then the default suffix set provided by
suffixing = TRUE will be c(NA, "L", "Cr"). This doesn't apply suffixes
to the thousands range, but does express values in lakhs and crores.
A formatting pattern that allows for decoration of the
formatted value. The value itself is represented by {x} and all other
characters are taken to be string literals.
The mark to use as a separator between groups of digits
(e.g., using sep_mark = "," with 1000 would result in a formatted value
of 1,000).
The character to use as a decimal mark (e.g., using dec_mark = "," with 0.152 would result in a formatted value of 0,152).
Should the positive sign be shown for positive values
(effectively showing a sign for all values except zero)? If so, use TRUE
for this option. The default is FALSE, where only negative numbers will
display a minus sign. This option is disregarded when using accounting
notation with accounting = TRUE.
The placement of the currency symbol. This can be either be
left (the default) or right.
An option for whether to include a space between the value and the currency symbol. The default is to not introduce a space character.
The numbering system to use. By default, this is the
international numbering system ("intl") whereby grouping separators
(i.e., sep_mark) are separated by three digits. The alternative system,
the Indian numbering system ("ind") uses grouping separators that
correspond to thousand, lakh, crore, and higher quantities.
An optional locale identifier that can be used for formatting
the value according the locale's rules. Examples include "en" for English
(United States) and "fr" for French (France). The use of a locale ID will
override any locale-specific values provided. We can use the
info_locales() function as a useful reference for all of the locales that
are supported.
The fmt_currency() formatting function is compatible with body cells that
are of the "numeric" or "integer" types. Any other types of body cells
are ignored during formatting. This is to say that cells of incompatible data
types may be targeted, but there will be no attempt to format them.
Targeting of values is done through columns and additionally by rows (if
nothing is provided for rows then entire columns are selected). The
columns argument allows us to target a subset of cells contained in the
resolved columns. We say resolved because aside from declaring column names
in c() (with bare column names or names in quotes) we can use
tidyselect-style expressions. This can be as basic as supplying a select
helper like starts_with(), or, providing a more complex incantation like
where(~ is.numeric(.x) && max(.x, na.rm = TRUE) > 1E6)
which targets numeric columns that have a maximum value greater than
1,000,000 (excluding any NAs from consideration).
By default all columns and rows are selected (with the everything()
defaults). Cell values that are incompatible with a given formatting function
will be skipped over, like character values and numeric fmt_*()
functions. So it's safe to select all columns with a particular formatting
function (only those values that can be formatted will be formatted), but,
you may not want that. One strategy is to format the bulk of cell values with
one formatting function and then constrain the columns for later passes with
other types of formatting (the last formatting done to a cell is what you get
in the final output).
Once the columns are targeted, we may also target the rows within those
columns. This can be done in a variety of ways. If a stub is present, then we
potentially have row identifiers. Those can be used much like column names in
the columns-targeting scenario. We can use simpler tidyselect-style
expressions (the select helpers should work well here) and we can use quoted
row identifiers in c(). It's also possible to use row indices (e.g.,
c(3, 5, 6)) though these index values must correspond to the row numbers of
the input data (the indices won't necessarily match those of rearranged rows
if row groups are present). One more type of expression is possible, an
expression that takes column values (can involve any of the available columns
in the table) and returns a logical vector. This is nice if you want to base
formatting on values in the column or another column, or, you'd like to use a
more complex predicate expression.
This formatting function can adapt outputs according to a provided locale
value. Examples include "en" for English (United States) and "fr" for
French (France). The use of a valid locale ID here means separator and
decimal marks will be correct for the given locale. Should any values be
provided in sep_mark or dec_mark, they will be overridden by the locale's
preferred values.
Note that a locale value provided here will override any global locale
setting performed in gt()'s own locale argument (it is settable there as
a value received by all other functions that have a locale argument). As a
useful reference on which locales are supported, we can use the
info_locales() function to view an info table.
Use exibble to create a gt table. Format the currency column to
have currency values in euros ("EUR").
exibble |>
gt() |>
fmt_currency(
columns = currency,
currency = "EUR"
)

Use exibble to create a gt table. Keep only the num and currency,
columns, then, format those columns using the "CNY" and "GBP" currencies.
exibble |>
dplyr::select(num, currency) |>
gt() |>
fmt_currency(
columns = num,
currency = "CNY"
) |>
fmt_currency(
columns = currency,
currency = "GBP"
)

3-8
v0.2.0.5 (March 31, 2020)
The vector-formatting version of this function:
vec_fmt_currency().
Other data formatting functions:
data_color(),
fmt_auto(),
fmt_bins(),
fmt_bytes(),
fmt_datetime(),
fmt_date(),
fmt_duration(),
fmt_engineering(),
fmt_flag(),
fmt_fraction(),
fmt_image(),
fmt_index(),
fmt_integer(),
fmt_markdown(),
fmt_number(),
fmt_partsper(),
fmt_passthrough(),
fmt_percent(),
fmt_roman(),
fmt_scientific(),
fmt_spelled_num(),
fmt_time(),
fmt_url(),
fmt(),
sub_large_vals(),
sub_missing(),
sub_small_vals(),
sub_values(),
sub_zero()